package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.OmsFeign;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/oms")
public class OMSController {


    @Autowired
    OmsFeign omsFeign;
    
    //********************************************omsTruckOrderController*****************************

    @ApiOperation(value = "查询所有运输订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(86)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllTruckOrder")
    public Map<String, Object> getAllTruckOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer orderStatus,
                                          Integer planId,
                                          Integer orderType,
                                                Integer fuelOrder) {
        return omsFeign.getAllTruckOrder(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize, orderStatus, planId, orderType, fuelOrder);
    }

    @ApiOperation(value = "不适用表头返回数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/getAllTruckOrderReturnListMap")
    public Map<String, Object> getAllTruckOrderReturnListMap(Integer orderStatus, Integer planId, Integer orderType) {
        return omsFeign.getAllTruckOrderReturnListMap(orderStatus, planId, orderType);
    }

    @ApiOperation(value = "查询所有空闲的运力信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(85)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllCapacity")
    public Map<String, Object> getAllCapacity(@RequestBody(required = false) Map<String, Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        Integer carrierId
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return omsFeign.getAllCapacity(mapValue, apiId, pageNum, pageSize, carrierId);
    }

    @ApiOperation(value = "分解运输计划后 新增订单  或者直接新增订单 ")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("/addPurOrder")
    public Map<String, Object> addPurOrder(@RequestBody(required = false) Map<String, Object> mapValue) {
        return omsFeign.addPurOrder(mapValue);
    }
    // == null ? new HashMap<>() : mapValue


    @ApiOperation(value = "修改分派计划")
    @PostMapping("/updateOrder")
    public Map<String, Object> updateOrder(@RequestBody Map<String, Object> map) {
        return omsFeign.updateOrder(map);
    }


    @ApiOperation(value = "派单")
    @PostMapping("/dispatchOrder")
    public Map<String, Object> dispatchOrder(@RequestBody(required = false) Map<String, Object> map) {
        return omsFeign.dispatchOrder(map);
    }

    @ApiOperation(value = "逻辑删除运单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deleteOrder")
    public Map<String, Object> deleteOrder(@RequestBody(required = false) Map<String, Object> map,
                                     Integer planId) {
        return omsFeign.deleteOrder(map, planId);
    }

    @ApiOperation(value = "司机接收、拒绝接单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/driverReceiveOrRefuse/{orderId}")
    public Map<String, Object> driverReceiveOrRefuse(@PathVariable("orderId") Integer orderId, Integer orderReceiveStatus) {
        return omsFeign.driverReceiveOrRefuse(orderId, orderReceiveStatus);
    }


    @ApiOperation(value="司机接单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveRefuseOrder/{orderReceiveStatus}")
    public Map<String, Object> getReceiveRefuseOrder(@RequestBody(required=false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               @PathVariable Integer orderReceiveStatus,
                                               Integer orderType,
                                               Integer orderStatus
    ){
        return omsFeign.getReceiveRefuseOrder(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum,
                pageSize, orderReceiveStatus, orderType, orderStatus);
    }


    @ApiOperation(value="司机APP端调用接口查询数据 4 已下发 5 已接收")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/sendMesToDriver")
    public Map<String, Object> sendMesToDriver(String capacityNumber, Integer orderStatus){
        return omsFeign.sendMesToDriver(capacityNumber, orderStatus);
    }

    @ApiOperation(value="通过车牌获取所有已拒绝的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "capacityNumber", value = "车牌号", required = false, dataType = "String"),
    })
    @PostMapping("/getRefuseOrderByCapacityNum")
    public Map<String, Object> sendMesToDriver(String capacityNumber){
        return omsFeign.sendMesToDriver(capacityNumber);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息 包含各个作业路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/getOrderMesByOrderNum/{orderId}")
    public Map<String, Object> getOrderMesByOrderNum(@PathVariable("orderId") Integer orderId){
        return omsFeign.getOrderMesByOrderNum(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询实绩地点和时间")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "运输订单Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/selectPlaceAndTime/{orderId}")
    public Map<String, Object> selectPlaceAndTime(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectPlaceAndTime(orderId);
    }

    @ApiOperation(value="通过运输订单ID查询运单信息")
    @PostMapping("/selectOrderByOrderId/{orderId}")
    public Map<String, Object> selectOrderByOrderId(@PathVariable("orderId") Integer orderId){
        return omsFeign.selectOrderByOrderId(orderId);
    }

    @ApiOperation(value="查看运输派单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(117)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping("/getTransportDispatch/{orderReceiveStatus}")
    public Map<String, Object> getTransportDispatch(@RequestBody(required=false) Map<String,Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize,
                                              @PathVariable Integer orderReceiveStatus,
                                              Integer orderType,
                                              Integer orderStatus,
                                                    Integer fuelOrder){
        return omsFeign.getTransportDispatch(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize,
                orderReceiveStatus, orderType, orderStatus, fuelOrder);
    }

    /**
     * 展示承运商接收销售公司已接受的销售订单
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getSaleOrderForCarrierList/{carrierId}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "168", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getSaleOrderForCarrierList(@PathVariable("carrierId") Integer carrierId,
                                                          Integer apiId,
                                                          Integer pageNum,
                                                          Integer pageSize) {
        return omsFeign.getSaleOrderForCarrierList(carrierId, apiId, pageNum, pageSize);

    }

    /**
     * 查询所有已经接收的焦炭发运日计划
     *
     * @param carrierId
     * @param apiId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @PostMapping("/getCokeDayPlanAndRecivedList")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "169", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getCokeDayPlanAndRecivedList(@PathVariable("carrierId") Integer carrierId,
                                                            @RequestParam Integer apiId,
                                                            @RequestParam Integer pageNum,
                                                            @RequestParam Integer pageSize) {
        return omsFeign.getCokeDayPlanAndRecivedList(carrierId, apiId, pageNum, pageSize);
    }

    /**
     * 查询所有已经接收的水渣发运日计划
     *
     * @param
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getWaterSlagDayPlanAndRecivedList")

    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId", value = "170", required = false, dataType = "BigDecimal"),
    })
    public Map<String, Object> getWaterSlagDayPlanAndRecivedList(@PathVariable("carrierId") Integer carrierId,
                                                                 @RequestParam Integer apiId,
                                                                 @RequestParam Integer pageNum,
                                                                 @RequestParam Integer pageSize) {
        return omsFeign.getWaterSlagDayPlanAndRecivedList(carrierId, apiId, pageNum, pageSize);
    }



}
